@@ -25,7 +25,8 @@ from typing import TYPE_CHECKING, Union
 
 from cylc.flow.hostuserutil import get_host
 from cylc.flow import LOG
-from cylc.rose.jinja2_parser import Parser
+import cylc.flow.flags as flags
+from cylc.rose.jinja2_parser import Parser, patch_jinja2_leading_zeros
 from metomi.rose import __version__ as ROSE_VERSION
 from metomi.isodatetime.datetimeoper import DateTimeOperator
 from metomi.rose.config import ConfigDumper, ConfigNodeDiff, ConfigNode
@@ -146,22 +147,26 @@ def get_rose_vars_from_config_node(config, config_node, environ):
     # Add the entire config to ROSE_SUITE_VARIABLES to allow for programatic
     # access.
     if templating is not None:
-        parser = Parser()
-        for key, value in config['template_variables'].items():
-            # The special variables are already Python variables.
-            if key not in ['ROSE_ORIG_HOST', 'ROSE_VERSION', 'ROSE_SITE']:
-                try:
-                    config['template_variables'][key] = (
-                        parser.literal_eval(value)
-                    )
-                except Exception:
-                    raise ConfigProcessError(
-                        [templating, key],
-                        value,
-                        f'Invalid template variable: {value}'
-                        '\nMust be a valid Python or Jinja2 literal'
-                        ' (note strings "must be quoted").'
-                    ) from None
+        with patch_jinja2_leading_zeros():
+            # BACK COMPAT: patch_jinja2_leading_zeros
+            # back support zero-padded integers for a limited time to help
+            # users migrate before upgrading cylc-flow to Jinja2>=3.1
+            parser = Parser()
+            for key, value in config['template_variables'].items():
+                # The special variables are already Python variables.
+                if key not in ['ROSE_ORIG_HOST', 'ROSE_VERSION', 'ROSE_SITE']:
+                    try:
+                        config['template_variables'][key] = (
+                            parser.literal_eval(value)
+                        )
+                    except Exception:
+                        raise ConfigProcessError(
+                            [templating, key],
+                            value,
+                            f'Invalid template variable: {value}'
+                            '\nMust be a valid Python or Jinja2 literal'
+                            ' (note strings "must be quoted").'
+                        ) from None
 
     # Add ROSE_SUITE_VARIABLES to config of templating engines in use.
     if templating is not None:
@@ -631,17 +636,25 @@ def deprecation_warnings(config_tree):
 
     deprecations = {
         'empy:suite.rc': (
-            "'empy:suite.rc' is deprecated."
+            "'rose-suite.conf[empy:suite.rc]' is deprecated."
             " Use [template variables] instead."),
         'jinja2:suite.rc': (
-            "'jinja2:suite.rc' is deprecated."
+            "'rose-suite.conf[jinja2:suite.rc]' is deprecated."
+            " Use [template variables] instead."),
+        'empy:flow.cylc': (
+            "'rose-suite.conf[empy:flow.cylc]' is not used by Cylc."
+            " Use [template variables] instead."),
+        'jinja2:flow.cylc': (
+            "'rose-suite.conf[jinja2:flow.cylc]' is not used by Cylc."
             " Use [template variables] instead."),
         'root-dir': (
-            'You have set "root-dir", which is not supported at '
+            'You have set "rose-suite.conf[root-dir]", '
+            'which is not supported at '
             'Cylc 8. Use `[install] symlink dirs` in global.cylc '
             'instead.')
     }
-    for string in list(config_tree.node):
-        for deprecation in deprecations.keys():
-            if deprecation in string:
-                LOG.warning(deprecations[deprecation])
+    if not flags.cylc7_back_compat:
+        for string in list(config_tree.node):
+            for deprecation in deprecations.keys():
+                if deprecation in string.lower():
+                    LOG.warning(deprecations[deprecation])
